vfbLib.parsers.cmap.CustomCmapParser
====================================

.. currentmodule:: vfbLib.parsers.cmap

.. autoclass:: CustomCmapParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CustomCmapParser.__init__
      ~CustomCmapParser.parse
      ~CustomCmapParser.parse_hex
      ~CustomCmapParser.read_double
      ~CustomCmapParser.read_doubles
      ~CustomCmapParser.read_float
      ~CustomCmapParser.read_floats
      ~CustomCmapParser.read_int16
      ~CustomCmapParser.read_int32
      ~CustomCmapParser.read_int8
      ~CustomCmapParser.read_str
      ~CustomCmapParser.read_str_all
      ~CustomCmapParser.read_uint16
      ~CustomCmapParser.read_uint32
      ~CustomCmapParser.read_uint8
      ~CustomCmapParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CustomCmapParser.encoding
      ~CustomCmapParser.master_count
      ~CustomCmapParser.stream
      ~CustomCmapParser.ttStemsH_count
      ~CustomCmapParser.ttStemsV_count
   
   